@@ -39,12 +39,21 @@ sub on_insert
 {
     my ( $self, %args ) = (@_);
 
-    my $data = $args{ 'data' };
+    my $config = $args{ 'config' };
+    my $data   = $args{ 'data' };
 
     #
     #  We'll return undef here, which will stop the insertion process
     #
-    return undef if ( $data->{ 'draft' } );
+    if ( $data->{ 'draft' } )
+    {
+        $config->{ 'verbose' } &&
+          print "Skipping draft: $data->{'filename'} \n";
+
+        ## no critic (ReturnUndef)
+        return undef;
+        ## use critic
+    }
 
     #
     #  Otherwise return the unmodified data.
